@@ -51,8 +51,8 @@ class RedisDriver(drivers.Driver):
             ["redis-server", "-"],
             stdin=("dir %s\nport %d\n"
                    % (self.tempdir, self.port)).encode('ascii'),
-            wait_for_line=b"The server is now ready to "
-            b"accept connections on port")
+            wait_for_line="The server is now ready to "
+            "accept connections on port")
 
         self.addCleanup(self._kill, c.pid)
 
@@ -66,7 +66,7 @@ sentinel monitor pifpaf localhost %d 1"""
 
             c, _ = self._exec(
                 ["redis-sentinel", cfg],
-                wait_for_line=b"# Sentinel runid is")
+                wait_for_line=r"# Sentinel (runid|ID) is")
 
             self.addCleanup(self._kill, c.pid)
 
